rusage class final

Inheritance
Implemented types
Available extensions

Constructors

rusage()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
ru_idrss ↔ int
getter/setter pair
ru_inblock ↔ int
getter/setter pair
ru_isrss ↔ int
getter/setter pair
ru_ixrss ↔ int
getter/setter pair
ru_majflt ↔ int
getter/setter pair
ru_maxrss ↔ int
getter/setter pair
ru_minflt ↔ int
getter/setter pair
ru_msgrcv ↔ int
getter/setter pair
ru_msgsnd ↔ int
getter/setter pair
ru_nivcsw ↔ int
getter/setter pair
ru_nsignals ↔ int
getter/setter pair
ru_nswap ↔ int
getter/setter pair
ru_nvcsw ↔ int
getter/setter pair
ru_oublock ↔ int
getter/setter pair
ru_stime ↔ timeval
getter/setter pair
ru_utime ↔ timeval
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited