sigevent class final

Inheritance
Implemented types
Available extensions

Constructors

sigevent()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sigev_notify ↔ int
getter/setter pair
sigev_notify_attributes ↔ Pointer<pthread_attr_t>
getter/setter pair
sigev_notify_function ↔ Pointer<NativeFunction<Void Function(sigval)>>
getter/setter pair
sigev_signo ↔ int
getter/setter pair
sigev_value ↔ sigval
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited